@@ -1,7 +1,6 @@
 from __future__ import absolute_import
 
-import six
-from django.utils.translation import gettext as _, ugettext
+from django.utils.translation import gettext as _
 
 from django_enumfield.exceptions import InvalidStatusOperationError
 
@@ -13,9 +12,7 @@ def validate_valid_transition(enum, from_value, to_value):
     """
     validate_available_choice(enum, to_value)
     if not enum.is_valid_transition(from_value, to_value):
-        message = _(
-            six.text_type('{enum} can not go from "{from_value}" to "{to_value}"')
-        )
+        message = _('{enum} can not go from "{from_value}" to "{to_value}"')
         raise InvalidStatusOperationError(
             message.format(
                 enum=enum.__name__,
@@ -37,9 +34,7 @@ def validate_available_choice(enum, to_value):
         enum(to_value)
     except ValueError:
         raise InvalidStatusOperationError(
-            ugettext(
-                six.text_type(
-                    "{value!r} is not one of the available choices " "for enum {enum}."
-                )
+            _(
+                "{value!r} is not one of the available choices " "for enum {enum}."
             ).format(value=to_value, enum=enum)
         )
